==> keystone-2013.2.4.tar.gz: keystone-2013.2.4/run_tests.sh <==
#!/bin/bash

# Copyright 2012 OpenStack Foundation
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

set -eu

function usage {
  echo "Usage: $0 [OPTION]..."
  echo "Run Keystone's test suite(s)"
  echo ""
  echo "  -V, --virtual-env        Always use virtualenv.  Install automatically if not present"
  echo "  -N, --no-virtual-env     Don't use virtualenv.  Run tests in local environment"
  echo "  -r, --recreate-db        Recreate the test database (deprecated, as this is now the default)."
  echo "  -n, --no-recreate-db     Don't recreate the test database."
  echo "  -x, --stop               Stop running tests after the first error or failure."
  echo "  -f, --force              Force a clean re-build of the virtual environment. Useful when dependencies have been added."
  echo "  -u, --update             Update the virtual environment with any newer package versions"
  echo "  -p, --pep8               Just run flake8"
  echo "  -8, --8                  Just run flake8, don't show PEP8 text for each error"
  echo "  -P, --no-pep8            Don't run flake8"
  echo "  -c, --coverage           Generate coverage report"
  echo "  -h, --help               Print this usage message"
  echo "  -xintegration            Ignore all keystoneclient test cases (integration tests)"
  echo "  --hide-elapsed           Don't print the elapsed time for each test along with slow test list"
  echo "  --standard-threads       Don't do the eventlet threading monkeypatch."
  echo ""
  echo "Note: with no options specified, the script will try to run the tests in a virtual environment,"
  echo "      If no virtualenv is found, the script will ask if you would like to create one.  If you "
  echo "      prefer to run tests NOT in a virtual environment, simply pass the -N option."
  exit
}

function process_option {
  case "$1" in
    -h|--help) usage;;
    -V|--virtual-env) always_venv=1; never_venv=0;;
    -N|--no-virtual-env) always_venv=0; never_venv=1;;
    -r|--recreate-db) recreate_db=1;;
    -n|--no-recreate-db) recreate_db=0;;
    -f|--force) force=1;;
    -u|--update) update=1;;
    -p|--pep8) just_flake8=1;;
    -8|--8) short_flake8=1;;
    -P|--no-pep8) no_flake8=1;;
    -c|--coverage) coverage=1;;
    -xintegration) nokeystoneclient=1;;
    --standard-threads)
        export STANDARD_THREADS=1
        ;;
    -*) noseopts="$noseopts $1";;
    *) noseargs="$noseargs $1"
  esac
}

venv=.venv
with_venv=tools/with_venv.sh
always_venv=0
never_venv=0
force=0
noseargs=
noseopts="--with-openstack --openstack-color"
wrapper=""
just_flake8=0
short_flake8=0
no_flake8=0
coverage=0
nokeystoneclient=0
recreate_db=1
update=0

for arg in "$@"; do
  process_option $arg
done

# If enabled, tell nose to collect coverage data
if [ $coverage -eq 1 ]; then
    noseopts="$noseopts --with-coverage --cover-package=keystone"
fi

if [ $nokeystoneclient -eq 1 ]; then
    # disable the integration tests
    noseopts="$noseopts -I test_keystoneclient* -I _test_import_auth_token.py"
fi

function cleanup_test_db {
  # Default test settings will leave around some test*.db files
  # TODO(termie): this could probably be moved into keystone/tests/__init__.py
  #               but there have been some issues with creating that
  #               file for some users
  rm -f keystone/tests/*.db
}

function run_tests {
  # Just run the test suites in current environment
  ${wrapper} $NOSETESTS
  # If we get some short import error right away, print the error log directly
  RESULT=$?
  if [ "$RESULT" -ne "0" ];
  then
    ERRSIZE=`wc -l run_tests.log | awk '{print \$1}'`
    if [ "$ERRSIZE" -lt "40" ];
    then
        cat run_tests.log
    fi
  fi
  return $RESULT
}

function run_flake8 {
  FLAGS=--show-pep8
  if [ $# -gt 0 ] && [ 'short' == ''$1 ]
  then
      FLAGS=''
  fi


  echo "Running flake8 ..."
  # Just run flake8 in current environment
  echo ${wrapper} flake8 $FLAGS | tee pep8.txt
  ${wrapper} flake8 $FLAGS | tee pep8.txt
}

NOSETESTS="nosetests $noseopts $noseargs"

if [ $never_venv -eq 0 ]
then
  # Remove the virtual environment if --force used
  if [ $force -eq 1 ]; then
    echo "Cleaning virtualenv..."
    rm -rf ${venv}
  fi
  if [ $update -eq 1 ]; then
    echo "Updating virtualenv..."
    python tools/install_venv.py
  fi
  if [ -e ${venv} ]; then
    wrapper="${with_venv}"
  else
    if [ $always_venv -eq 1 ]; then
      # Automatically install the virtualenv
      python tools/install_venv.py
      wrapper="${with_venv}"
    else
      echo -e "No virtual environment found...create one? (Y/n) \c"
      read use_ve
      if [ "x$use_ve" = "xY" -o "x$use_ve" = "x" -o "x$use_ve" = "xy" ]; then
        # Install the virtualenv and run the test suite in it
        python tools/install_venv.py
        wrapper=${with_venv}
      fi
    fi
  fi
fi

# Delete old coverage data from previous runs
if [ $coverage -eq 1 ]; then
    ${wrapper} coverage erase
fi

if [ $just_flake8 -eq 1 ]; then
    run_flake8
    exit
fi

if [ $short_flake8 -eq 1 ]; then
     run_flake8 short
     exit
fi


if [ $recreate_db -eq 1 ]; then
    cleanup_test_db
fi

run_tests

# NOTE(sirp): we only want to run flake8 when we're running the full-test
# suite, not when we're running tests individually. To handle this, we need to
# distinguish between options (noseopts), which begin with a '-', and arguments
# (noseargs).
if [ -z "$noseargs" ]; then
  if [ $no_flake8 -eq 0 ]; then
    run_flake8
  fi
fi

if [ $coverage -eq 1 ]; then
    echo "Generating coverage report in covhtml/"
    ${wrapper} coverage html -d covhtml -i
fi

==> keystone-2014.1.b1.tar.gz: keystone-2014.1.b1/run_tests.sh <==
#!/bin/bash

# Copyright 2012 OpenStack Foundation
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

set -eu

function usage {
  echo "Usage: $0 [OPTION]..."
  echo "Run Keystone's test suite(s)"
  echo ""
  echo "  -V, --virtual-env        Always use virtualenv.  Install automatically if not present"
  echo "  -N, --no-virtual-env     Don't use virtualenv.  Run tests in local environment"
  echo "  -r, --recreate-db        Recreate the test database (deprecated, as this is now the default)."
  echo "  -n, --no-recreate-db     Don't recreate the test database."
  echo "  -x, --stop               Stop running tests after the first error or failure."
  echo "  -f, --force              Force a clean re-build of the virtual environment. Useful when dependencies have been added."
  echo "  -u, --update             Update the virtual environment with any newer package versions"
  echo "  -p, --pep8               Just run flake8"
  echo "  -8, --8                  Just run flake8, don't show PEP8 text for each error"
  echo "  -P, --no-pep8            Don't run flake8"
  echo "  -c, --coverage           Generate coverage report"
  echo "  -h, --help               Print this usage message"
  echo ""
  echo "Note: with no options specified, the script will try to run the tests in a virtual environment,"
  echo "      If no virtualenv is found, the script will ask if you would like to create one.  If you "
  echo "      prefer to run tests NOT in a virtual environment, simply pass the -N option."
  exit
}

function process_option {
  case "$1" in
    -h|--help) usage;;
    -V|--virtual-env) always_venv=1; never_venv=0;;
    -N|--no-virtual-env) always_venv=0; never_venv=1;;
    -r|--recreate-db) recreate_db=1;;
    -n|--no-recreate-db) recreate_db=0;;
    -f|--force) force=1;;
    -u|--update) update=1;;
    -p|--pep8) just_flake8=1;;
    -8|--8) short_flake8=1;;
    -P|--no-pep8) no_flake8=1;;
    -c|--coverage) coverage=1;;
    -*) testropts="$testropts $1";;
    *) testrargs="$testrargs $1"
  esac
}

venv=.venv
with_venv=tools/with_venv.sh
always_venv=0
never_venv=0
force=0
testrargs=
testropts=--subunit
wrapper=""
just_flake8=0
short_flake8=0
no_flake8=0
coverage=0
recreate_db=1
update=0

for arg in "$@"; do
  process_option $arg
done

TESTRTESTS="python setup.py testr"

# If enabled, tell nose to collect coverage data
if [ $coverage -eq 1 ]; then
    TESTRTESTS="$TESTRTESTS --coverage"
fi

function cleanup_test_db {
  # Default test settings will leave around some test*.db files
  # TODO(termie): this could probably be moved into keystone/tests/__init__.py
  #               but there have been some issues with creating that
  #               file for some users
  rm -f keystone/tests/*.db
}

function run_tests {
  set -e
  echo ${wrapper}
  ${wrapper} $TESTRTESTS --testr-args="$testropts $testrargs" | \
      ${wrapper} subunit-2to1 | \
      ${wrapper} tools/colorizer.py
}

function run_flake8 {
  FLAGS=--show-pep8
  if [ $# -gt 0 ] && [ 'short' == ''$1 ]
  then
      FLAGS=''
  fi

  echo "Running flake8 ..."
  # Just run flake8 in current environment
  echo ${wrapper} flake8 $FLAGS | tee pep8.txt
  ${wrapper} flake8 $FLAGS | tee pep8.txt
}

echo "This script is now deprecated.  Please use tox instead."
echo "Checkout http://tox.readthedocs.org/en/latest/ for information on tox."
echo "[press enter to continue]"
read

if [ $never_venv -eq 0 ]
then
  # Remove the virtual environment if --force used
  if [ $force -eq 1 ]; then
    echo "Cleaning virtualenv..."
    rm -rf ${venv}
  fi
  if [ $update -eq 1 ]; then
    echo "Updating virtualenv..."
    python tools/install_venv.py
  fi
  if [ -e ${venv} ]; then
    wrapper="${with_venv}"
  else
    if [ $always_venv -eq 1 ]; then
      # Automatically install the virtualenv
      python tools/install_venv.py
      wrapper="${with_venv}"
    else
      echo -e "No virtual environment found...create one? (Y/n) \c"
      read use_ve
      if [ "x$use_ve" = "xY" -o "x$use_ve" = "x" -o "x$use_ve" = "xy" ]; then
        # Install the virtualenv and run the test suite in it
        python tools/install_venv.py
        wrapper=${with_venv}
      fi
    fi
  fi
fi

# Delete old coverage data from previous runs
if [ $coverage -eq 1 ]; then
    ${wrapper} coverage erase
fi

if [ $just_flake8 -eq 1 ]; then
    run_flake8
    exit
fi

if [ $short_flake8 -eq 1 ]; then
     run_flake8 short
     exit
fi


if [ $recreate_db -eq 1 ]; then
    cleanup_test_db
fi

run_tests

# NOTE(sirp): we only want to run flake8 when we're running the full-test
# suite, not when we're running tests individually. To handle this, we need to
# distinguish between options (testropts), which begin with a '-', and arguments
# (testrargs).
if [ -z "$testrargs" ]; then
  if [ $no_flake8 -eq 0 ]; then
    run_flake8
  fi
fi
